The logger show() method produces a plot of the iterations, on the X-axis, vs the duration of each iteration, on the Y-axis.
When report is set to TRUE the duration is also reported each
iteration.
new()DurationLogger$new(report = FALSE)
log_status()DurationLogger$log_status(nodes, iteration)
show()DurationLogger$show()
clone()The objects of this class are cloneable with this method.
DurationLogger$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.