get_node_connection_type: Determines the type of a node

Description Usage Arguments Value

View source: R/get_node_connection_type.R

Description

Determines whether a node is a Start, Middle, or End type node.

Usage

1
get_node_connection_type(connection_matrix, node_index)

Arguments

connection_matrix

A matrix where the non zero elements what connections exist. The rows indicate the node where the edge is going to, and the columns indicates the node where the edge is coming from.

node_index

a number indicating of which node the type is being determined.

Value

A string indicating the type of node using "Start", "End", or "Middle"


GeertPostma/pathmodelr documentation built on Oct. 5, 2021, 4:17 p.m.