initializer_string_to_function: Converts initializer string names to function handle

Description Usage Arguments Details Value

View source: R/initializer_string_to_function.R

Description

This is an internal function used to convert each implemented initialiser name to its corresponding function handle.

Usage

1

Arguments

initializer_name

A string indicating the name of the initialiser method.

Details

Supported options are: PCA and Full. The conversion renders the name case-insensitive.

Value

A function handle to an initialiser function which takes a node as an argument.


GeertPostma/pathmodelr documentation built on Oct. 5, 2021, 4:17 p.m.