Description Usage Arguments Value
View source: R/get_node_connection_type.R
Determines whether a node is a Start, Middle, or End type node.
1 | get_node_connection_type(connection_matrix, node_index)
|
connection_matrix |
A matrix where the non zero elements what connections exist. The rows indicate the node where the edge is going to, and the columns indicates the node where the edge is coming from. |
node_index |
a number indicating of which node the type is being determined. |
A string indicating the type of node using "Start", "End", or "Middle"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.