Description Usage Arguments Details Value
View source: R/initializer_string_to_function.R
This is an internal function used to convert each implemented initialiser name to its corresponding function handle.
1 | initializer_string_to_function(initializer_name)
|
initializer_name |
A string indicating the name of the initialiser method. |
Supported options are: PCA and Full. The conversion renders the name case-insensitive.
A function handle to an initialiser function which takes a node as an argument.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.